==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Alle Schriftarten</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinesisch</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Nichtproportional</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Deaktivieren</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Beschädigte Datei</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Gleiche Version installiert</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Systemschriftart</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Strg+Umschalt+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>BildAuf</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>BildAb</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Strg+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Strg+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Schriftarten</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Strg+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Strg+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Strg+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Schriftart %1 installiert</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 Schriftarten installiert</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>Strg+I</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Beschädigte Datei</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Diese Schriftart wird nicht für Anwendungen verfügbar sein</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Diese Schriftarten werden nicht für Anwendungen verfügbar sein</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Sind Sie sicher, %1 Schriftarten zu entfernen?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Schriftarten werden gelöscht, bitte warten ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Überprüfung der Schriftart</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Es werden keine Schriftarten installiert</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Fortsetzen</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Franz jagt im komplett verwahrlosten Taxi quer durch Bayern</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Basisinformationen</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Vollständiger Name</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps-Name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Markenzeichen</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Schriftarten-Manager</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Schriftarten-Manager hilft den Benutzern bei der Installation und Verwaltung von Schriften.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Schriftarten werden geladen, bitte warten ...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Die Schriftart wurde auf Ihren Desktop exportiert</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 Schriftarten wurde auf Ihren Desktop exportiert</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Fehlgeschlagen bei Exportierung von Schriftart %1. Es gibt keinen ausreichenden Speicherplatz.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Schriftart hinzufügen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Kein Favorit</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deaktiviert</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Die Schriftarten wurden deaktiviert</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 wird benutzt. Sie können es daher leider nicht deaktivieren.</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Sie können die Schriftarten vom System nicht deaktivieren.</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Schriftart installieren</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Wird verifiziert ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Beschädigte Datei</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installiert</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nicht installiert</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Schriftart installieren</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Keine Schriftarten</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Verknüpfungen anzeigen</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Bild auf</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Bild ab</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Schriftart hinzufügen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Kein Favorit</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Schriftartinformationen</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Vorschautext eingeben</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.13.orig.tar.xz: deepin-font-manager-5.9.13/translations/deepin-font-manager_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Alle Schriftarten</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinesisch</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Nichtproportional</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 ist eine Schriftenfamilie. Wenn Sie fortsetzen, werden alle Schriften darin gelöscht</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 ist eine Schriftenfamilie. Wenn Sie fortsetzen, werden alle Schriften darin aktiviert</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 ist eine Schriftenfamilie. Wenn Sie fortsetzen, werden alle Schriften darin deaktiviert</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Deaktivieren</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Auf alle ausgewählten Schriftfamilien anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Beschädigte Datei</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Gleiche Version installiert</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Systemschriftart</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Strg+Umschalt+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>BildAuf</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>BildAb</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Strg+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Strg+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Strg+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Strg+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Strg+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Schriftart %1 installiert</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 Schriftarten installiert</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>Strg+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Diese Schriftart wird nicht für Anwendungen verfügbar sein</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Diese Schriftarten werden nicht für Anwendungen verfügbar sein</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Die anderen %1 Systemschriftarten können nicht gelöscht werden</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Die Schriftart &quot;%1&quot; kann nicht gelöscht werden, da sie gerade verwendet wird</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Die anderen %1 Systemschriftarten und die gerade verwendete Schriftart &quot;%2&quot; können nicht gelöscht werden </translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Sind Sie sicher, %1 Schriftarten zu entfernen?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Schriftarten werden gelöscht, bitte warten ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Überprüfung der Schriftart</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Es werden keine Schriftarten installiert</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Fortsetzen</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Basisinformationen</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Vollständiger Name</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps-Name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Markenzeichen</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Schriftarten-Manager</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Schriftarten-Manager hilft den Benutzern bei der Installation und Verwaltung von Schriften.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Schriftarten werden geladen, bitte warten ...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Die Schriftart wurde auf Ihren Desktop exportiert</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 Schriftarten wurde auf Ihren Desktop exportiert</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 Schriftart konnte nicht exportiert werden. Es ist nicht genug Speicherplatz verfügbar-</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Fehlgeschlagen bei Exportierung von Schriftart %1. Es gibt keinen ausreichenden Speicherplatz.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Schriftart hinzufügen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Kein Favorit</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deaktiviert</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Die Schriftarten wurden deaktiviert</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 wird benutzt. Sie können es daher leider nicht deaktivieren.</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Sie können Systemschriftarten und gerade verwendete Schriftarten nicht deaktivieren</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Sie können die Schriftarten vom System nicht deaktivieren.</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Schriftart installieren</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Wird verifiziert ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Beschädigte Datei</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installiert</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nicht installiert</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Schriftart installieren</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Keine Schriftarten</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Verknüpfungen anzeigen</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Bild auf</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Bild ab</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Schriftart hinzufügen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Kein Favorit</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Schriftartinformationen</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Vorschautext eingeben</translation>
    </message>
</context>
</TS>
